summaryrefslogtreecommitdiff
path: root/src/passes/TranslateEH.cpp
diff options
context:
space:
mode:
authorHeejin Ahn <aheejin@gmail.com>2024-01-30 17:26:39 -0800
committerGitHub <noreply@github.com>2024-01-30 17:26:39 -0800
commitcf14a9fa9cd6f99ef78a5ffa70cfcb024a524919 (patch)
tree44a80e74df693c1754d01ceb64eecdf80b839050 /src/passes/TranslateEH.cpp
parent8504571fb7209d07670a06c42a868bbfc954c756 (diff)
downloadbinaryen-cf14a9fa9cd6f99ef78a5ffa70cfcb024a524919.tar.gz
binaryen-cf14a9fa9cd6f99ef78a5ffa70cfcb024a524919.tar.bz2
binaryen-cf14a9fa9cd6f99ef78a5ffa70cfcb024a524919.zip
[EH] Change translator option name (#6259)
The previous name feels too verbose and unwieldy. This also removes the "new-to-old EH" placeholder. I think it'd be better to add it back when it is actually added.
Diffstat (limited to 'src/passes/TranslateEH.cpp')
-rw-r--r--src/passes/TranslateEH.cpp25
1 files changed, 4 insertions, 21 deletions
diff --git a/src/passes/TranslateEH.cpp b/src/passes/TranslateEH.cpp
index d8a004468..760c4b656 100644
--- a/src/passes/TranslateEH.cpp
+++ b/src/passes/TranslateEH.cpp
@@ -15,7 +15,7 @@
*/
//
// TranslateEHOldToNew translates the old Phase 3 EH instructions, which include
// try, catch, catch_all, delegate, and rethrow, into the new EH instructions,
// which include try_table (with catch / catch_ref / catch_all / catch_all_ref)
// and throw_ref, passed at the Oct 2023 CG meeting. This translator can be used
@@ -24,12 +24,6 @@
// end of the Binaryen pipeline to produce binaries for the new spec while the
// end-to-end toolchain implementation for the new spec is in progress.
//
-// TODO
-// TranslateEHNewToOld translates the new EH instructions to the old ones. This
-// can be used as a stopgap tool while Binaryen implementation for the whole
-// optimization pipeline is not complete but we need to test our LLVM
-// implementation for the new spec. This has not been implemented yet.
-//
#include <ir/drop.h>
#include <ir/find_all.h>
@@ -45,8 +39,7 @@ namespace {
// Translates the old EH instructions (try / catch / catch_all / delegate /
// rethrow) into the new ones (try_table (+ catch / catch_ref / catch_all /
// catch_all_ref) / throw_ref).
-struct TranslateEHOldToNew
- : public WalkerPass<PostWalker<TranslateEHOldToNew>> {
+struct TranslateToNewEH : public WalkerPass<PostWalker<TranslateToNewEH>> {
bool isFunctionParallel() override { return true; }
// Scans and records which try labels are targeted by delegates and rethrows.
@@ -201,10 +194,8 @@ struct TranslateEHOldToNew
// exnref) tuples for a short time.
std::unordered_map<Type, Index> typeToScratchLocal;
- bool refinalize = false;
-
std::unique_ptr<Pass> create() override {
- return std::make_unique<TranslateEHOldToNew>();
+ return std::make_unique<TranslateToNewEH>();
}
// Get a scratch local for a given type. These locals are used to contain
@@ -680,7 +671,6 @@ struct TranslateEHOldToNew
}
void visitTry(Try* curr) {
- refinalize = true;
Builder builder(*getModule());
Block* outerBlock = nullptr;
auto it = delegateTargetToBrTarget.find(curr->name);
@@ -807,15 +797,8 @@ struct TranslateEHOldToNew
}
};
-struct TranslateEHNewToOld
- : public WalkerPass<PostWalker<TranslateEHNewToOld>> {
- // TODO
-};
-
} // namespace
-Pass* createTranslateEHOldToNewPass() { return new TranslateEHOldToNew(); }
-
-Pass* createTranslateEHNewToOldPass() { return new TranslateEHNewToOld(); }
+Pass* createTranslateToNewEHPass() { return new TranslateToNewEH(); }
} // namespace wasm
@@ -15,7 +15,7 @@
*/
//
-// TranslateEHOldToNew translates the old Phase 3 EH instructions, which include
+// TranslateToNewEH translates the old Phase 3 EH instructions, which include
// try, catch, catch_all, delegate, and rethrow, into the new EH instructions,
// which include try_table (with catch / catch_ref / catch_all / catch_all_ref)